## START: Set by rpmautospec
## (rpmautospec version 0.6.0)
## RPMAUTOSPEC: autorelease, autochangelog
%define autorelease(e:s:pb:n) %{?-p:0.}%{lua:
    release_number = 3;
    base_release_number = tonumber(rpm.expand("%{?-b*}%{!?-b:1}"));
    print(release_number + base_release_number - 1);
}%{?-e:.%{-e*}}%{?-s:.%{-s*}}%{!?-n:%{?dist}}
## END: Set by rpmautospec

%global srcname healpy
%global sum Python healpix maps tools

Name:           python-%{srcname}
Version:        1.16.5
Release:        %autorelease
Summary:        %{sum}

License:        GPL-2.0-or-later
URL:            https://pypi.python.org/pypi/%{srcname}
Source0:        https://files.pythonhosted.org/packages/source/h/%{srcname}/%{srcname}-%{version}.tar.gz


# Upstream only supports 64 bit architectures, 32 Bit builds, but tests fail
# and we don't want to provide a non reliable software.
# Check https://github.com/healpy/healpy/issues/194
# Also explicitly exclude known unsupported architectures
ExcludeArch:    %{ix86} %{arm}

# Common build requirements
BuildRequires:  cfitsio-devel
BuildRequires:  gcc-c++
BuildRequires:  healpix-c++-devel
BuildRequires:  python3-Cython
BuildRequires:  python3-devel
BuildRequires:  zlib-devel

# tests requirements
BuildRequires:  python3dist(astropy)
BuildRequires:  python3dist(pytest)
BuildRequires:  python3dist(pytest-astropy)
BuildRequires:  python3dist(pytest-runner)
BuildRequires:  python3dist(requests)


%description
Healpy provides a python package to manipulate healpix maps. It is based on the
standard numeric and visualisation tools for Python, Numpy and matplotlib.

%package -n python3-%{srcname}
Summary:        %{sum}

%description -n python3-%{srcname}
Healpy provides a python package to manipulate healpix maps. It is based on the
standard numeric and visualisation tools for Python, Numpy and matplotlib.

This package contains the Python 3 modules.


%prep
%autosetup -p1 -n %{srcname}-%{version}

# kill rpath forcely (mtasaka, 20210704)
# "runtime_library_dirs" seems to invoke ""-Wl,--enable-new-dtags,-R"
# from python3-setuptools: runtime_library_dir_option (unixccompiler.py) <-
#                          gen_lib_options (ccompiler.py),
# so remove setting "runtime_library_dirs" for now
# sed -i setup.py -e 's|"runtime_library_dirs"||'

# Fedora doesn't have 'oldest-supported-numpy'
sed -i pyproject.toml -e 's|"oldest-supported-numpy"|"numpy"|'

# Remove pre-generated CPython files
# not strictly necessary as these files are not used from bundled cfitsio
find -type f -name '*.c' -print -delete

%generate_buildrequires
%pyproject_buildrequires


%build
%pyproject_wheel


%install
%pyproject_install
rm -f %{buildroot}%{_bindir}/healpy_get_wmap_maps.sh
%pyproject_save_files healpy


%check
%pyproject_check_import

pushd %{buildroot}/%{python3_sitearch}
# For skipped tests: They require internet access and therefore have to be disabled
%pytest -q -k "not (test_astropy_download_file or test_rotate_map_polarization or test_pixelweights_local_datapath)" healpy
# Remove relict from tests
rm -rf .pytest_cache
popd


%files -n python3-%{srcname} -f %{pyproject_files}
%license COPYING
%doc CHANGELOG.rst CITATION README.rst


%changelog
## START: Generated by rpmautospec
* Fri Jan 26 2024 Fedora Release Engineering <releng@fedoraproject.org> - 1.16.5-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_40_Mass_Rebuild

* Mon Jan 22 2024 Fedora Release Engineering <releng@fedoraproject.org> - 1.16.5-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_40_Mass_Rebuild

* Sun Sep 17 2023 Mattia Verga <mattia.verga@proton.me> - 1.16.5-1
- Update to 1.16.5 (fedora#2138105)
- Fix FTB (fedora#2226206)
- Migrate license to SPDX

* Fri Jul 21 2023 Fedora Release Engineering <releng@fedoraproject.org> - 1.16.1-8
- Rebuilt for https://fedoraproject.org/wiki/Fedora_39_Mass_Rebuild

* Tue Jun 27 2023 Python Maint <python-maint@redhat.com> - 1.16.1-7
- Rebuilt for Python 3.12

* Fri Jan 20 2023 Fedora Release Engineering <releng@fedoraproject.org> - 1.16.1-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_38_Mass_Rebuild

* Thu Dec 29 2022 Maxwell G <gotmax@e.email> - 1.16.1-5
- Rebuild for cfitsio 4.2

* Sun Aug 07 2022 Mattia Verga <mattia.verga@proton.me> - 1.16.1-4
- Use autorelease

* Sun Aug 07 2022 Mattia Verga <mattia.verga@proton.me> - 1.16.1-2
- Add back license and docs to RPM bundling

* Sun Aug 07 2022 Mattia Verga <mattia.verga@proton.me> - 1.16.1-1
- Update to 1.16.1
- use libhealpix_cxx from healpix rather than the bundled one
- switch to modern python build macros

* Fri Jul 22 2022 Fedora Release Engineering <releng@fedoraproject.org> - 1.15.0-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_37_Mass_Rebuild

* Wed Jun 15 2022 Python Maint <python-maint@redhat.com> - 1.15.0-3
- Rebuilt for Python 3.11

* Fri Jan 21 2022 Fedora Release Engineering <releng@fedoraproject.org> - 1.15.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_36_Mass_Rebuild

* Fri Dec 31 2021 Christian Dersch <lupinix@fedoraproject.org> - 1.15.0-1
- new version

* Fri Jul 23 2021 Fedora Release Engineering <releng@fedoraproject.org> - 1.14.0-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_35_Mass_Rebuild

* Sun Jul  4 2021 Mamoru TASAKA <mtasaka@fedoraproject.org> - 1.14.0-6
- Kill rpath forcely by removing "runtime_library_dirs" env from python-setuptools
- BR: python3-scipy for %%check

* Fri Jun 04 2021 Python Maint <python-maint@redhat.com> - 1.14.0-5
- Rebuilt for Python 3.10

* Tue Feb 02 2021 Christian Dersch <lupinix@mailbox.org> - 1.14.0-4
- Rebuilt for libcfitsio.so.9

* Wed Jan 27 2021 Fedora Release Engineering <releng@fedoraproject.org> - 1.14.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_34_Mass_Rebuild

* Wed Jul 29 2020 Fedora Release Engineering <releng@fedoraproject.org> - 1.14.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_33_Mass_Rebuild

* Thu Jul 23 2020 Christian Dersch <lupinix@fedoraproject.org> - 1.14.0-1
- new version

* Mon Jul 20 2020 Christian Dersch <lupinix@fedoraproject.org> - 1.13.0-1
- new version

* Tue May 26 2020 Miro Hrončok <mhroncok@redhat.com> - 1.12.9-6
- Rebuilt for Python 3.9

* Thu Jan 30 2020 Fedora Release Engineering <releng@fedoraproject.org> - 1.12.9-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_32_Mass_Rebuild

* Thu Oct 03 2019 Miro Hrončok <mhroncok@redhat.com> - 1.12.9-4
- Rebuilt for Python 3.8.0rc1 (#1748018)

* Mon Aug 19 2019 Miro Hrončok <mhroncok@redhat.com> - 1.12.9-3
- Rebuilt for Python 3.8

* Fri Jul 26 2019 Fedora Release Engineering <releng@fedoraproject.org> - 1.12.9-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_31_Mass_Rebuild

* Fri Mar 29 2019 Christian Dersch <lupinix@fedoraproject.org> - 1.12.9-1
- new version
- system libs now detected automatically, no more patch needed

* Sat Feb 02 2019 Fedora Release Engineering <releng@fedoraproject.org> - 1.12.4-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_30_Mass_Rebuild

* Tue Oct 02 2018 Christian Dersch <lupinix@fedoraproject.org> - 1.12.4-2
- Drop python2 subpackage

* Tue Oct 02 2018 Christian Dersch <lupinix@fedoraproject.org> - 1.12.4-1
- new version

* Sat Jul 14 2018 Fedora Release Engineering <releng@fedoraproject.org> - 1.12.3-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Sat Jun 30 2018 Christian Dersch <lupinix@mailbox.org> - 1.12.3-1
- new version

* Sat Jun 30 2018 Christian Dersch <lupinix@mailbox.org> - 1.12.2-1
- new version

* Sat Jun 30 2018 Christian Dersch <lupinix@mailbox.org> - 1.12.0-4
- Use GitHub tar instead of PyPI one (as GitHub one is not Cythonized)

* Tue Jun 19 2018 Christian Dersch <lupinix@fedoraproject.org> - 1.12.0-3
- Use bundled copies of healpix and cfitsio for now due to upstream changes

* Tue Jun 19 2018 Miro Hrončok <mhroncok@redhat.com> - 1.12.0-2
- Rebuilt for Python 3.7

* Tue Jun 19 2018 Christian Dersch <lupinix@fedoraproject.org> - 1.12.0-1
- new version

* Sat May 26 2018 Christian Dersch <lupinix@mailbox.org> - 1.11.0-5
- rebuilt for cfitsio 3.450

* Sat Feb 24 2018 Christian Dersch <lupinix@mailbox.org> - 1.11.0-4
- rebuilt for cfitsio 3.420 (so version bump)

* Wed Feb 14 2018 Christian Dersch <lupinix@mailbox.org> - 1.11.0-3
- rebuilt

* Fri Feb 09 2018 Fedora Release Engineering <releng@fedoraproject.org> - 1.11.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Sun Oct 08 2017 Christian Dersch <lupinix@mailbox.org> - 1.11.0-1
- new version

* Thu Aug 03 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1.10.3-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Binutils_Mass_Rebuild

* Thu Jul 27 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1.10.3-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Thu Jun 01 2017 Christian Dersch <lupinix@mailbox.org> - 1.10.3-2
- enable s390x architecture

* Fri Apr 07 2017 Christian Dersch <lupinix@mailbox.org> - 1.10.3-1
- initial package (review: rhbz #1440216)

## END: Generated by rpmautospec
